@@ -7,7 +7,7 @@ use Storable;
 use Digest::MD5 qw(md5_hex);
 use vars qw($VERSION);
 
-$VERSION = '1.48';
+$VERSION = '1.50';
 
 my $GOT_KILLFAM;
 
@@ -281,6 +281,7 @@ sub _sig_child {
   warn "$thing $pid $status\n" if $self->{debug};
   $kernel->delay( '_wheel_idle' );
   delete $self->{_digests};
+  delete $self->{_loop_detect};
   my $job = delete $self->{_current_job};
   $job->{status} = $status;
   my $log = delete $self->{_wheel_log};
@@ -353,6 +354,7 @@ sub _spawn_wheel {
   }
   $self->{_wheel_log} = [ ];
   $self->{_digests} = { };
+  $self->{_loop_detect} = 0;
   $self->{_current_job} = $job;
   $job->{PID} = $self->{wheel}->PID();
   $job->{start_time} = time();
@@ -407,10 +409,11 @@ sub _wheel_stderr {
 sub _detect_loop {
   my $self = shift;
   my $input = shift || return;
+  return if $self->{_loop_detect};
   my $digest = md5_hex( $input );
   $self->{_digests}->{ $digest }++;
   return unless ++$self->{_digests}->{ $digest } > 300;
-  return 1;
+  return $self->{_loop_detect} = 1;
 }
 
 sub _wheel_idle {
